/*****************************************************************************
 *
 * Copyright (C) 2012-2021  Florian Pose <fp@igh.de>
 *                    2013  Dr. Wilhelm Hagemeister <hm@igh-essen.com>
 *
 * This file is part of the QtPdWidgets library.
 *
 * The QtPdWidgets library is free software: you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License as
 * published by the Free Software Foundation, either version 3 of the License,
 * or (at your option) any later version.
 *
 * The QtPdWidgets library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser
 * General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with the QtPdWidgets Library. If not, see
 * <http://www.gnu.org/licenses/>.
 *
 ****************************************************************************/

#ifndef PD_TABLECOLUMN_H
#define PD_TABLECOLUMN_H

#include <QColor>
#include <QHash>
#include <QObject>
#include <QString>

#include <pdcom5/Process.h>

namespace Pd {

/****************************************************************************/

/** Table Column.
 */
class Q_DECL_EXPORT TableColumn:
    public QObject
{
    Q_OBJECT

    public:
        TableColumn(const QString & = QString());
        ~TableColumn();

        void setHeader(const QString &);
        const QString &getHeader() const;

        void setVariable(PdCom::Variable, double = 0.0, double = 1.0,
                double = 0.0);
        void setVariable(PdCom::Process *, const QString &, double = 0.0,
                double = 1.0, double = 0.0);
        void clearVariable();
        void clearData();

        quint32 getDecimals() const;
        void setDecimals(quint32);

        unsigned int getRows() const;

        QVariant data(unsigned int, int) const;
        QVariant headerData(int) const;
        Qt::ItemFlags flags(unsigned int) const;
        bool setData(unsigned int, const QString &, int);
        void setEnabled(bool, int = -1);

        bool isEditing() const;
        bool isEnabled() const;
        void commit();
        void revert();

        void setHighlightRow(int);

        void setHighlightColor(QColor);
        void setDisabledColor(QColor);

        /** Exception type.
         */
        struct Exception {
            /** Constructor.
             */
            Exception(const QString &msg): msg(msg) {}
            QString msg; /**< Exception message. */
        };

    signals:
        void dimensionChanged();
        void headerChanged();
        void valueChanged();

    private:
        class Impl;
        std::unique_ptr<Impl> impl;
};

/****************************************************************************/

} // namespace

#endif
